@@ -31,7 +31,8 @@ def main():
 
     with ActiveCampaignClient(parsed_args.config['api_url'],
                               parsed_args.config['api_token'],
-                              parsed_args.config['user_agent']) as client:
+                              parsed_args.config['user_agent'],
+                              parsed_args.config.get('request_timeout')) as client:
 
         state = {}
         if parsed_args.state:
