@@ -34,6 +34,14 @@ def get_schemas():
             valid_replication_keys=stream_metadata.get('replication_keys', None),
             replication_method=stream_metadata.get('replication_method', None)
         )
+        mdata = metadata.to_map(mdata)
+        # Loop through all keys and make replication keys of automatic inclusion
+        for field_name in schema['properties'].keys():
+            
+            if stream_metadata.get('replication_keys') and field_name in stream_metadata.get('replication_keys'):
+                mdata = metadata.write(mdata, ('properties', field_name), 'inclusion', 'automatic')
+
+        mdata = metadata.to_list(mdata)
         field_metadata[stream_name] = mdata
 
     return schemas, field_metadata
