@@ -25,6 +25,6 @@ def transform_json(this_json, stream_name, data_key):
     else:
         converted_json = humps.decamelize(this_json)
     
-    fixed_records = fix_records(converted_json)
+    fix_records(converted_json)
 
     return converted_json
